@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef SFCGAL_CAPI_H_
@@ -338,6 +339,20 @@ sfcgal_geometry_as_obj_file(const sfcgal_geometry_t *, const char *filename);
 SFCGAL_API void
 sfcgal_geometry_as_obj(const sfcgal_geometry_t *, char **buffer, size_t *len);
 
+/**
+ * Creates a STL string of the given geometry
+ * @ingroup capi
+ */
+SFCGAL_API void
+sfcgal_geometry_as_stl(const sfcgal_geometry_t *, char **buffer, size_t *len);
+
+/**
+ * Creates a STL file of the given geometry
+ * @ingroup capi
+ */
+SFCGAL_API void
+sfcgal_geometry_as_stl_file(const sfcgal_geometry_t *, const char *filename);
+
 /**
  * Creates an empty point
  * @ingroup capi
@@ -487,8 +502,6 @@ sfcgal_triangle_vertex(const sfcgal_geometry_t *triangle, int i);
  * Sets one vertex of a Triangle
  * @pre triangle must be a Triangle
  * @pre vertex must be a Point
- * @post returns a pointer to one of the vertices as a Point. This pointer is
- * not writable and must not be deallocated by the caller
  * @ingroup capi
  */
 SFCGAL_API void
@@ -566,6 +579,8 @@ sfcgal_polygon_interior_ring_n(const sfcgal_geometry_t *polygon, size_t i);
  * Adds an interior ring to a given Polygon
  * @pre polygon must be a Polygon
  * @pre ring must be a LineString
+ * @post the ownership of the given ring is taken. The caller is not responsible
+ * anymore of its deallocation
  * @ingroup capi
  */
 SFCGAL_API void
@@ -605,8 +620,8 @@ sfcgal_geometry_collection_geometry_n(const sfcgal_geometry_t *collection,
  * Set the ith geometry of a given GeometryCollection
  * @pre collection is a GeometryCollection
  * @pre i >= 0 and i < sfcgal_geometry_num_geometries( collection )
- * The ownership of the geometry is taken. The caller is not responsible anymore
- * of its deallocation.
+ * @post The ownership of the geometry is taken. The caller is not responsible
+ * anymore of its deallocation.
  * @ingroup capi
  */
 SFCGAL_API void
@@ -721,8 +736,8 @@ sfcgal_polyhedral_surface_add_patch(sfcgal_geometry_t *polyhedral,
  * @pre polyhedral must be a PolyhedralSurface.
  * @pre patch must be a Polygon.
  * @pre i >= 0 and i < sfcgal_polyhedral_surface_num_patches(polyhedral)
- * The ownership of the polygon is taken. The caller is not responsible anymore
- * of its deallocation.
+ * @post The ownership of the polygon is taken. The caller is not responsible
+ * anymore of its deallocation.
  * @ingroup capi
  */
 SFCGAL_API void
@@ -797,8 +812,8 @@ sfcgal_triangulated_surface_triangle_n(const sfcgal_geometry_t *tin, size_t i);
  * @pre tin must be a TriangulatedSurface
  * @pre patch must be a Triangle.
  * @pre i >= 0 and i < sfcgal_triangulated_surface_num_patches( tin )
- * The ownership of the triangle is taken. The caller is not responsible anymore
- * of its deallocation.
+ * @post The ownership of the triangle is taken. The caller is not responsible
+ * anymore of its deallocation.
  * @ingroup capi
  */
 SFCGAL_API void
