@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef SFCGAL_TRANSFORM_FORCE_ORDER_POINTS_H_
@@ -29,13 +30,13 @@ public:
   /*
    * [SFCGAL::Transform]
    */
-  virtual void
-  transform(Point &p);
+  void
+  transform(Point &p) override;
 
-  virtual void
-  visit(Triangle &);
-  virtual void
-  visit(Polygon &);
+  void
+  visit(Triangle &) override;
+  void
+  visit(Polygon &) override;
 
 private:
   bool _orientCCW;
